@@ -2,7 +2,7 @@
 // pandora: Sydbox's Dump Inspector & Profile Writer
 // pandora.rs: Main entry point
 //
-// Copyright (c) 2021 Alï  Polatel <alip@exherbo.org>
+// Copyright (c) 2021 Alï Polatel <alip@exherbo.org>
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -407,7 +407,7 @@ core/trace/use_seize:true
 core/trace/use_toolong_hack:true
 
 core/match/case_sensitive:true
-core/match/no_wildcard:prefix
+core/match/no_wildcard:literal
 
 # Safe defaults for system paths
 whitelist/write+/dev/stdout
